@@ -88,10 +88,10 @@ default_fun <- function(data) {
 
 accelerometer_fun <- function(data) {
   # Determine whether this is a continuous accelerometer or periodic
-  if (length(data$body[[1]]$body) == 5) {
-    data <- default_fun(data)
-  } else {
+  if (!is.null(data$body[[1]]$body$data)) {
     data <- periodic_accelerometer_fun(data)
+  } else {
+    data <- default_fun(data)
   }
 
   # Put into right data format
@@ -100,12 +100,21 @@ accelerometer_fun <- function(data) {
     participant_id = data$participant_id,
     date = substr(data$timestamp, 1, 10),
     time = substr(data$timestamp, 12, 23),
+    timezone = data$timezone,
     x = data$x,
     y = data$y,
-    z = data$z
+    z = data$z,
+    x_mean = data$xm,
+    y_mean = data$ym,
+    z_mean = data$zm,
+    x_mean_sq = data$xms,
+    y_mean_sq = data$yms,
+    z_mean_sq = data$zms,
+    n = data$n
   )
 }
 
+# Periodic accelerometer is archived with the introduction of on-phone accelerometer binning
 periodic_accelerometer_fun <- function(data) {
   data$id <- vapply(data$body, function(x) x$body$id, character(1), USE.NAMES = FALSE)
   data$body <- lapply(data$body, function(x) x$body$data)
@@ -133,6 +142,7 @@ activity_fun <- function(data) {
     participant_id = data$participant_id,
     date = substr(data$start_time, 1, 10),
     time = substr(data$start_time, 12, 19),
+    timezone = data$timezone,
     confidence = data$confidence,
     type = data$type
   )
@@ -146,6 +156,7 @@ air_quality_fun <- function(data) {
     participant_id = data$participant_id,
     date = substr(data$start_time, 1, 10),
     time = substr(data$start_time, 12, 19),
+    timezone = data$timezone,
     air_quality_index = data$air_quality_index,
     air_quality_level = data$air_quality_level,
     source = data$source,
@@ -177,6 +188,7 @@ app_usage_fun <- function(data) {
     participant_id = data$participant_id,
     date = substr(data$start_time, 1, 10),
     time = substr(data$start_time, 12, 19),
+    timezone = data$timezone,
     start = data$start,
     end = data$end,
     usage = data$usage,
@@ -199,8 +211,7 @@ apps_fun <- function(data) {
   data <- unnest(data, "apps", keep_empty = TRUE)
 
   # TODO: Consider unique ID constraint Temporary fix
-  ids <-
-    stats::ave(numeric(nrow(data)) + 1, data$id, FUN = seq_along)
+  ids <- stats::ave(numeric(nrow(data)) + 1, data$id, FUN = seq_along)
   data$id <- paste0(data$id, "_", ids)
 
   safe_data_frame(
@@ -208,6 +219,7 @@ apps_fun <- function(data) {
     participant_id = data$participant_id,
     date = substr(data$start_time, 1, 10),
     time = substr(data$start_time, 12, 19),
+    timezone = data$timezone,
     app = data$apps
   )
 }
@@ -220,6 +232,7 @@ battery_fun <- function(data) {
     participant_id = data$participant_id,
     date = substr(data$start_time, 1, 10),
     time = substr(data$start_time, 12, 19),
+    timezone = data$timezone,
     battery_level = data$battery_level,
     battery_status = data$battery_status
   )
@@ -241,6 +254,7 @@ bluetooth_fun <- function(data) {
     participant_id = data$participant_id,
     date = substr(data$start_time, 1, 10),
     time = substr(data$start_time, 12, 19),
+    timezone = data$timezone,
     advertisement_name = data$advertisement_name,
     bluetooth_device_id = data$bluetooth_device_id,
     bluetooth_device_name = data$bluetooth_device_name,
@@ -307,6 +321,7 @@ calendar_fun <- function(data) {
     participant_id = data$participant_id,
     date = substr(data$start_time, 1, 10),
     time = substr(data$start_time, 12, 19),
+    timezone = data$timezone,
     event_id = data$event_id,
     calendar_id = data$calendar_id,
     title = data$title,
@@ -327,6 +342,7 @@ connectivity_fun <- function(data) {
     participant_id = data$participant_id,
     date = substr(data$start_time, 1, 10),
     time = substr(data$start_time, 12, 19),
+    timezone = data$timezone,
     connectivity_status = data$connectivity_status
   )
 }
@@ -339,6 +355,7 @@ device_fun <- function(data) {
     participant_id = data$participant_id,
     date = substr(data$start_time, 1, 10),
     time = substr(data$start_time, 12, 19),
+    timezone = data$timezone,
     platform = data$platform,
     device_id = data$device_id,
     hardware = data$hardware,
@@ -357,6 +374,7 @@ error_fun <- function(data) {
     participant_id = data$participant_id,
     date = substr(data$start_time, 1, 10),
     time = substr(data$start_time, 12, 19),
+    timezone = data$timezone,
     message = data$message
   )
 }
@@ -369,6 +387,7 @@ geofence_fun <- function(data) {
     participant_id = data$participant_id,
     date = substr(data$start_time, 1, 10),
     time = substr(data$start_time, 12, 19),
+    timezone = data$timezone,
     center = data$center,
     dwell = data$dwell,
     name = data$name,
@@ -396,6 +415,7 @@ light_fun <- function(data) {
     participant_id = data$participant_id,
     date = substr(data$start_time, 1, 10),
     time = substr(data$start_time, 12, 19),
+    timezone = data$timezone,
     mean_lux = data$mean_lux,
     std_lux = data$std_lux,
     min_lux = data$min_lux,
@@ -411,6 +431,7 @@ location_fun <- function(data) {
     participant_id = data$participant_id,
     date = substr(data$start_time, 1, 10),
     time = substr(data$start_time, 12, 19),
+    timezone = data$timezone,
     latitude = data$latitude,
     longitude = data$longitude,
     altitude = data$altitude,
@@ -429,6 +450,7 @@ memory_fun <- function(data) {
     participant_id = data$participant_id,
     date = substr(data$start_time, 1, 10),
     time = substr(data$start_time, 12, 19),
+    timezone = data$timezone,
     free_physical_memory = data$free_physical_memory,
     free_virtual_memory = data$free_virtual_memory
   )
@@ -443,6 +465,7 @@ mobility_fun <- function(data) {
     participant_id = data$participant_id,
     date = substr(data$start_time, 1, 10),
     time = substr(data$start_time, 12, 19),
+    timezone = data$timezone,
     number_of_places = data$number_of_places,
     location_variance = data$location_variance,
     entropy = data$entropy,
@@ -460,6 +483,7 @@ noise_fun <- function(data) {
     participant_id = data$participant_id,
     date = substr(data$start_time, 1, 10),
     time = substr(data$start_time, 12, 19),
+    timezone = data$timezone,
     mean_decibel = data$mean_decibel,
     std_decibel = data$std_decibel,
     min_decibel = data$min_decibel,
@@ -491,6 +515,7 @@ phone_log_fun <- function(data) {
     participant_id = data$participant_id,
     date = substr(data$start_time, 1, 10),
     time = substr(data$start_time, 12, 19),
+    timezone = data$timezone,
     call_type = data$call_type,
     datetime = data$datetime,
     duration = data$duration,
@@ -508,6 +533,7 @@ pedometer_fun <- function(data) {
     participant_id = data$participant_id,
     date = substr(data$start_time, 1, 10),
     time = substr(data$start_time, 12, 19),
+    timezone = data$timezone,
     step_count = data$step_count
   )
 }
@@ -520,6 +546,7 @@ screen_fun <- function(data) {
     participant_id = data$participant_id,
     date = substr(data$start_time, 1, 10),
     time = substr(data$start_time, 12, 19),
+    timezone = data$timezone,
     screen_event = data$screen_event
   )
 }
@@ -541,6 +568,7 @@ text_message_fun <- function(data) {
     participant_id = data$participant_id,
     date = substr(data$start_time, 1, 10),
     time = substr(data$start_time, 12, 19),
+    timezone = data$timezone,
     address = data$address,
     body = data$body,
     text_date = data$date,
@@ -561,6 +589,7 @@ weather_fun <- function(data) {
     participant_id = data$participant_id,
     date = substr(data$start_time, 1, 10),
     time = substr(data$start_time, 12, 19),
+    timezone = data$timezone,
     country = data$country,
     area_name = data$area_name,
     weather_main = data$weather_main,
@@ -592,6 +621,7 @@ wifi_fun <- function(data) {
     participant_id = data$participant_id,
     date = substr(data$start_time, 1, 10),
     time = substr(data$start_time, 12, 19),
+    timezone = data$timezone,
     ssid = data$ssid,
     bssid = data$bssid,
     ip = data$ip
