@@ -37,9 +37,17 @@ measurement_id TEXT NOT NULL,
 participant_id TEXT NOT NULL,
 date TEXT NOT NULL,
 time TEXT NOT NULL,
+timezone TEXT,
 x REAL,
 y REAL,
 z REAL,
+x_mean REAL,
+y_mean REAL,
+z_mean REAL,
+x_mean_sq REAL,
+y_mean_sq REAL,
+z_mean_sq REAL,
+n INTEGER,
 PRIMARY KEY (measurement_id),
 FOREIGN KEY (participant_id) REFERENCES Participant(participant_id) ON DELETE CASCADE
 );
@@ -50,6 +58,7 @@ measurement_id TEXT NOT NULL,
 participant_id TEXT NOT NULL,
 date TEXT NOT NULL,
 time TEXT NOT NULL,
+timezone TEXT,
 confidence INTEGER,
 type TEXT,
 PRIMARY KEY (measurement_id),
@@ -62,6 +71,7 @@ measurement_id TEXT NOT NULL,
 participant_id TEXT NOT NULL,
 date TEXT NOT NULL,
 time TEXT NOT NULL,
+timezone TEXT,
 air_quality_index INTEGER,
 air_quality_level TEXT,
 source TEXT,
@@ -78,6 +88,7 @@ measurement_id TEXT NOT NULL,
 participant_id TEXT NOT NULL,
 date TEXT NOT NULL,
 time TEXT NOT NULL,
+timezone TEXT,
 start TEXT,
 end TEXT,
 usage INTEGER,
@@ -92,6 +103,7 @@ measurement_id TEXT NOT NULL,
 participant_id TEXT NOT NULL,
 date TEXT NOT NULL,
 time TEXT NOT NULL,
+timezone TEXT,
 battery_level INTEGER,
 battery_status TEXT,
 PRIMARY KEY (measurement_id),
@@ -104,6 +116,7 @@ measurement_id TEXT NOT NULL,
 participant_id TEXT NOT NULL,
 date TEXT NOT NULL,
 time TEXT NOT NULL,
+timezone TEXT,
 advertisement_name TEXT,
 bluetooth_device_id TEXT,
 bluetooth_device_name TEXT,
@@ -121,8 +134,9 @@ measurement_id TEXT NOT NULL,
 participant_id TEXT NOT NULL,
 date TEXT NOT NULL,
 time TEXT NOT NULL,
-event_id INTEGER,
-calendar_id INTEGER,
+timezone TEXT,
+event_id TEXT,
+calendar_id TEXT,
 title TEXT,
 description TEXT,
 start TEXT,
@@ -140,6 +154,7 @@ measurement_id TEXT NOT NULL,
 participant_id TEXT NOT NULL,
 date TEXT NOT NULL,
 time TEXT NOT NULL,
+timezone TEXT,
 connectivity_status TEXT,
 PRIMARY KEY (measurement_id),
 FOREIGN KEY (participant_id) REFERENCES Participant(participant_id) ON DELETE CASCADE
@@ -151,6 +166,7 @@ measurement_id TEXT NOT NULL,
 participant_id TEXT NOT NULL,
 date TEXT NOT NULL,
 time TEXT NOT NULL,
+timezone TEXT,
 device_id TEXT,
 hardware TEXT,
 device_name TEXT,
@@ -168,6 +184,7 @@ measurement_id TEXT NOT NULL,
 participant_id TEXT NOT NULL,
 date TEXT NOT NULL,
 time TEXT NOT NULL,
+timezone TEXT,
 message TEXT,
 PRIMARY KEY (measurement_id),
 FOREIGN KEY (participant_id) REFERENCES Participant(participant_id) ON DELETE CASCADE
@@ -179,6 +196,7 @@ measurement_id TEXT NOT NULL,
 participant_id TEXT NOT NULL,
 date TEXT NOT NULL,
 time TEXT NOT NULL,
+timezone TEXT,
 center REAL,
 dwell INTEGER,
 name TEXT,
@@ -194,9 +212,17 @@ measurement_id TEXT NOT NULL,
 participant_id TEXT NOT NULL,
 date TEXT NOT NULL,
 time TEXT NOT NULL,
+timezone TEXT,
 x REAL,
 y REAL,
 z REAL,
+x_mean REAL,
+y_mean REAL,
+z_mean REAL,
+x_mean_sq REAL,
+y_mean_sq REAL,
+z_mean_sq REAL,
+n INTEGER,
 PRIMARY KEY (measurement_id),
 FOREIGN KEY (participant_id) REFERENCES Participant(participant_id) ON DELETE CASCADE
 );
@@ -207,6 +233,7 @@ measurement_id TEXT NOT NULL,
 participant_id TEXT NOT NULL,
 date TEXT NOT NULL,
 time TEXT NOT NULL,
+timezone TEXT,
 app TEXT,
 PRIMARY KEY (measurement_id),
 FOREIGN KEY (participant_id) REFERENCES Participant(participant_id) ON DELETE CASCADE
@@ -218,6 +245,7 @@ measurement_id TEXT NOT NULL,
 participant_id TEXT NOT NULL,
 date TEXT NOT NULL,
 time TEXT NOT NULL,
+timezone TEXT,
 body TEXT,
 end TEXT,
 start TEXT,
@@ -231,6 +259,7 @@ measurement_id TEXT NOT NULL,
 participant_id TEXT NOT NULL,
 date TEXT NOT NULL,
 time TEXT NOT NULL,
+timezone TEXT,
 mean_lux REAL,
 std_lux REAL,
 min_lux REAL,
@@ -245,6 +274,7 @@ measurement_id TEXT NOT NULL,
 participant_id TEXT NOT NULL,
 date TEXT NOT NULL,
 time TEXT NOT NULL,
+timezone TEXT,
 latitude BLOB,
 longitude BLOB,
 altitude REAL,
@@ -262,6 +292,7 @@ measurement_id TEXT NOT NULL,
 participant_id TEXT NOT NULL,
 date TEXT NOT NULL,
 time TEXT NOT NULL,
+timezone TEXT,
 free_physical_memory INTEGER,
 free_virtual_memory INTEGER,
 PRIMARY KEY (measurement_id),
@@ -274,6 +305,7 @@ measurement_id TEXT NOT NULL,
 participant_id TEXT NOT NULL,
 date TEXT NOT NULL,
 time TEXT NOT NULL,
+timezone TEXT,
 number_of_places INTEGER,
 location_variance REAL,
 entropy REAL,
@@ -290,6 +322,7 @@ measurement_id TEXT NOT NULL,
 participant_id TEXT NOT NULL,
 date TEXT NOT NULL,
 time TEXT NOT NULL,
+timezone TEXT,
 mean_decibel REAL,
 std_decibel REAL,
 min_decibel REAL,
@@ -304,6 +337,7 @@ measurement_id TEXT NOT NULL,
 participant_id TEXT NOT NULL,
 date TEXT NOT NULL,
 time TEXT NOT NULL,
+timezone TEXT,
 step_count INTEGER,
 PRIMARY KEY (measurement_id),
 FOREIGN KEY (participant_id) REFERENCES Participant(participant_id) ON DELETE CASCADE
@@ -315,6 +349,7 @@ measurement_id TEXT NOT NULL,
 participant_id TEXT NOT NULL,
 date TEXT NOT NULL,
 time TEXT NOT NULL,
+timezone TEXT,
 call_type TEXT,
 datetime TEXT,
 duration INTEGER,
@@ -331,6 +366,7 @@ measurement_id TEXT NOT NULL,
 participant_id TEXT NOT NULL,
 date TEXT NOT NULL,
 time TEXT NOT NULL,
+timezone TEXT,
 screen_event TEXT,
 PRIMARY KEY (measurement_id),
 FOREIGN KEY (participant_id) REFERENCES Participant(participant_id) ON DELETE CASCADE
@@ -342,6 +378,7 @@ measurement_id TEXT NOT NULL,
 participant_id TEXT NOT NULL,
 date TEXT NOT NULL,
 time TEXT NOT NULL,
+timezone TEXT,
 address TEXT,
 body TEXT,
 text_date TEXT,
@@ -360,6 +397,7 @@ measurement_id TEXT NOT NULL,
 participant_id TEXT NOT NULL,
 date TEXT NOT NULL,
 time TEXT NOT NULL,
+timezone TEXT,
 country TEXT,
 area_name TEXT,
 weather_main TEXT,
@@ -390,6 +428,7 @@ measurement_id TEXT NOT NULL,
 participant_id TEXT NOT NULL,
 date TEXT NOT NULL,
 time TEXT NOT NULL,
+timezone TEXT,
 ssid TEXT,
 bssid TEXT,
 ip TEXT,
